docs.rs failed to build rmquickjs-sys-0.0.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
rmquickjs
High-level MicroQuickJS bindings for Rust
rmquickjs is a library that provides a high-level API for MicroQuickJS, an embedded JS runtime created by the author of QuickJS.
This library is inspired by the existing Rust bindings mquickjs-rs, but rmquickjs offers more features and a more ergonomic API.
Features
- High-level API for the MicroQuickJS C API
- Supports function calls between Rust and JS
- no_std support
Installation
Quick Start
use *;
Constraints
- User-defined classes are not supported.
- In MicroQuickJS, user-defined functions and classes must be known at compile time. Implementing this via FFI is difficult.
- Support for functions is achieved by adding extensions to the MicroQuickJS source code.
- The following standard library functions are not implemented. They return
undefinedwhen called:print(),gc(),Date.now(),performance.now(),setTimeout(),clearTimeout()
License
This library is provided under the MIT License.